# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 3
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

# Original framework from Netrender
# Original Octane script from Enrico Cerica
# This script by Lionel Zamouth

import bpy
from bpy.props import *
from  octanerender.utils import *

# Button for exporting only
class BUTTON_OCT_export_(bpy.types.Operator):
	bl_idname = "button_export"
	bl_label = "Export OBJ/MTL only"
	bl_description = "Only export OBJ/MTL"

	@classmethod
	def poll(cls, context):
		return True

	def execute(self, context):
		scene = context.scene
		octane_render = scene.octane_render

		log ('Exporting OBJ/MTL only')
		octanerender.export_mode='export'
		bpy.ops.render.render()
		notify_user (self)
		return{'FINISHED'}

	def invoke(self, context, event):
		return self.execute(context)

# Button for rendering Still Image
class BUTTON_OCT_render(bpy.types.Operator):
	bl_idname = "button_render"
	bl_label = "Render Still Image"
	bl_description = "Export OBJ/MTL, create OCS if it doesn't exist and render"

	@classmethod
	def poll(cls, context):
		return True

	def execute(self, context):
		scene = context.scene
		octane_render = scene.octane_render

		log ('Rendering still image')
		octanerender.export_mode='still'
		bpy.ops.render.render()
		octane_render.replace_project = False
		notify_user (self)
		return{'FINISHED'}

	def invoke(self, context, event):
		return self.execute(context)

# Button for rendering animation
class BUTTON_OCT_animation(bpy.types.Operator):
	bl_idname = "button_animation"
	bl_label = "Render Animation"
	bl_description = "Export OBJ/MTL and render animation frame(s)"

	@classmethod
	def poll(cls, context):
		return True

	def execute(self, context):
		scene = context.scene
		octane_render = scene.octane_render

		log ('Rendering animation from frame #%d to #%d' % (scene.frame_start,scene.frame_end))
		currentFrame = scene.frame_current
		scene.frame_set(scene.frame_start)
		octanerender.export_mode='anim'
		bpy.ops.render.render()
		# Restore the current frame before starting animation
		context.scene.frame_set(currentFrame)
		octane_render.replace_project = False
		notify_user (self)
		return{'FINISHED'}

	def invoke(self, context, event):
		return self.execute(context)

# Button for rendering camera animation only
class BUTTON_OCT_fly(bpy.types.Operator):
	bl_idname = "button_fly"
	bl_label = "Camera Animation"
	bl_description = "Export OBJ/MTL only once and render animation frame(s)"

	@classmethod
	def poll(cls, context):
		return True

	def execute(self, context):
		scene = context.scene
		octane_render = scene.octane_render

		if octane_render.export_camera == False and octane_render.export_sundir == False:
			update_status(2,'You must export camera and/or sun in this mode')
			notify_user (self)
			return{'FINISHED'}
		log ('Rendering camera/light only animation from frame #%d to #%d' % (scene.frame_start,scene.frame_end))
		currentFrame = scene.frame_current
		scene.frame_set(scene.frame_start)
		octanerender.export_mode='fly'
		bpy.ops.render.render()
		# Restore the current frame before starting animation
		context.scene.frame_set(currentFrame)
		octane_render.replace_project = False
		notify_user (self)
		return{'FINISHED'}

	def invoke(self, context, event):
		return self.execute(context)

# Button to push active camera into camera name field
class BUTTON_OCT_select_camera(bpy.types.Operator):
	bl_idname = "button_select_camera"
	bl_label = "Select"
	bl_description = "Select active camera"

	@classmethod
	def poll(cls, context):
		return True

	def execute(self, context):
		scene = context.scene
		octane_render = scene.octane_render
		if scene.objects.active.type=='CAMERA':
			octane_render.active_camera=scene.objects.active.name
			update_status(0,'Camera <%s> assigned to Octane exporter' % scene.objects.active.name)
		else:
			update_status(2,'<%s> is not a CAMERA' % scene.objects.active.name)
		notify_user (self)
		return{'FINISHED'}

	def invoke(self, context, event):
		return self.execute(context)

# Button to push active light into light name field
class BUTTON_OCT_select_light_source(bpy.types.Operator):
	bl_idname = "button_select_light_source"
	bl_label = "Select"
	bl_description = "Select active light source"

	@classmethod
	def poll(cls, context):
		return True

	def execute(self, context):
		scene = context.scene
		octane_render = scene.octane_render
		if scene.objects.active.type=='LAMP':
			octane_render.active_light = scene.objects.active.name
			update_status(0,'Lamp <%s> assigned to Octane exporter' % scene.objects.active.name)
		else:
			update_status(2,'<%s> is not a LAMP' % scene.objects.active.name)
		notify_user (self)
		return{'FINISHED'}

	def invoke(self, context, event):
		return self.execute(context)

# Manage samples presets
class PRESET_export_samples(bpy.types.Operator):
	bl_idname = "menu_export_presets"
	bl_label = "Samples Presets"
	#bl_options = {'REGISTER', 'UNDO'}

	export_samples_presets = EnumProperty(  
		name="Presets",
		description="Samples per image presets",
		items=(
			("0",  "Very Low (8)", ""),
			("1", "Low (32)", ""),
			("2",  "Medium (256)", ""),
			("3",  "Medium/High (512)", ""),
			("4",  "High (1024)", ""),
			("5",  "Very High (4096)", ""),
			("6",  "Too High (8192)", ""),
			("7",  "Insane (16384)", "")
			),
		default= "2")

	def execute(self, context):
		#global export_samples_presets
		scene = context.scene
		octane_render = scene.octane_render
		octane_render.export_samples_per_image = {"0": 8, "1": 32, "2": 256, "3": 512, "4": 1024, "5": 4096, "6": 8192, "7": 16384	}[self.properties.export_samples_presets]
		return {'FINISHED'}

IS_RUNNING = False
class PROPERTIES_aspect_fix(bpy.types.Operator):
	bl_idname = 'aspect.fix'
	bl_label ="Keeps 1:1 pixels"
	bl_options = {'REGISTER'}
    
	def modal(self, context, event):
		#self.maintain(context)
		rd = bpy.context.scene.render
		if rd.pixel_aspect_x != 1:
			rd.pixel_aspect_x =1
			log ('Reset pixel to square')
		if rd.pixel_aspect_y != 1:
			rd.pixel_aspect_y = 1
			log ('Reset pixel to square')
		return {'PASS_THROUGH'}
                
	def execute(self, context):
		wm = context.window_manager
		global IS_RUNNING
		if context.area.type == 'PROPERTIES':
			if not IS_RUNNING:
				IS_RUNNING = True
				print("Aspect ratio fix installed")
				#wm.modal_handler_add(self)
		return {'RUNNING_MODAL'}
