# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 3
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

# Original framework from Netrender
# Original Octane script from Enrico Cerica
# This script by Lionel Zamouth

import bpy, os
import octanerender
from octanerender.labels import getLabel

class OctaneRenderSettings(bpy.types.IDPropertyGroup):
	pass

def addProperties():
	from bpy.props import PointerProperty, StringProperty, BoolProperty, EnumProperty, IntProperty, CollectionProperty, FloatProperty
	bpy.types.Scene.octane_render = PointerProperty(type=OctaneRenderSettings, name="Octane Render", description="Octane Render Settings")

# Octane Render Plug-in
	OctaneRenderSettings.panel_mode = EnumProperty(
		items=(
			("MODE_RENDER", "Image",     "Render still image"),
			("MODE_EXPORT", "Export",    "Only exports to OBJ/MTL"),
			("MODE_ANIM",   "Animation", "Render animation"),
			("MODE_FLY",    "Fly",       "Render camera animation only"),
			),
		name="Panel Mode",
		description="Render/Export target",
		default="MODE_RENDER")

	OctaneRenderSettings.image_output = StringProperty(
		name="Animation Output",
		description="Output path for animation frames",
		maxlen = 200,
		default = "",
		subtype='FILE_PATH')

				
	OctaneRenderSettings.export_samples_per_image = IntProperty(
		attr="",
		name="Samples",
		description="Samples per image",
		min=4,
		max=64000,
		default=256)
				
#	OctaneRenderSettings.export_samples_presets = EnumProperty(  
#		name="Presets",
#		description="Samples per image presets",
#		items=(
#			("0",  "Very Low (8)", ""),
#			("1", "Low (32)", ""),
#			("2",  "Medium (256)", ""),
#			("3",  "Medium/High (512)", ""),
#			("4",  "High (1024)", ""),
#			("5",  "Very High (4096)", ""),
#			("6",  "Too High (8192)", ""),
#			("7",  "Insane (16384)", "")
#			),
#		default= "2")

	OctaneRenderSettings.export_samples_per_image_old = IntProperty(
		name="Previous Samples",
		description="Previous Samples",
		min=4,
		max=64000,
		default = 256)

# Octane Project Settings
	OctaneRenderSettings.path = StringProperty(
		name="Project Path",
		description="Requires Absolute Path",
		maxlen = 128,
		default = "",
		subtype='DIR_PATH')

	OctaneRenderSettings.project_name = StringProperty(
		name="Project name",
		description="Octane project name",
		maxlen = 128,
		default = "")

	OctaneRenderSettings.unit_size = EnumProperty(  
		name="Native Unit Size",
		description="Native Units",
		items=(
			("11",  "Miles", ""),
			("10", "Furlongs", ""),
			("9",   "Yards", ""),
			("8",   "Feets", ""),
			("7",   "Inches", ""),
			("6",   "Kilometers", ""),
			("5",   "Hectometers", ""),
			("4",   "Decameters", ""),
			("3",   "Meters", ""),
			("2",   "Decimeters", ""),
			("1",   "Centimeters", ""),
			("0",   "Milimeters", "")
			),
		default= "3")

# Octane Environement Settings

	OctaneRenderSettings.replace_project = BoolProperty(
		name=getLabel('replace_project'),
		description="Will destroy material setup in Octane",
		default = False)

	OctaneRenderSettings.relink_obj = BoolProperty(
		name="Relink OBJ to existing OCS",
		description="Force OBJ mesh file to relink into rendered OCS",
		# TOGGLE
		default = octanerender.Supported)

	# Camera Properties
	OctaneRenderSettings.export_camera = BoolProperty(
		name=getLabel('export_camera'),
		description="Select camera and click button",
		default = True)

	OctaneRenderSettings.active_camera = StringProperty(
		name=getLabel('active_camera'),
		description="Active Camera",
		maxlen = 128,
		default = "")

	OctaneRenderSettings.lens_aperture = BoolProperty(
		name=getLabel('lens_aperture'),
		description="Lens Aperture",
		default = False)

	OctaneRenderSettings.lens_aperture_value = FloatProperty(
		attr="",
		name="Value",
		description="Value",
		soft_min=-1, soft_max=100, step = 100.0, default=1.0)

	OctaneRenderSettings.lens_aperture_curve = BoolProperty(
		name="Curve",
		description="Curve - Not implemented yet",
		default = False)

	OctaneRenderSettings.focal_depth = BoolProperty(
		name=getLabel('focal_depth'),
		description="Depth of field",
		default = False)

	OctaneRenderSettings.focal_depth_value = FloatProperty(
		name="Value",
		description="Value",
		soft_min = 0.0,
		soft_max = 100.0,
		step = 100,
		default=5.0)

	OctaneRenderSettings.focal_depth_curve = BoolProperty(
		name="Curve",
		description="Curve - Not implemented yet",
		default = False)

	OctaneRenderSettings.camera_motion = BoolProperty(
		name="Camera Motion",
		description="Use camera motion for animation",
		default = False)

	OctaneRenderSettings.interpolate_frame = EnumProperty(  
		name="Interpolate",
		description="Interpolate frame",
		items=(
			("0",  "Next", ""),
			("1", "Previous", "")
			),
		default= "0")

	#Daylight Environment
	OctaneRenderSettings.export_sundir = BoolProperty(
		name=getLabel('export_sundir'),
		description="Export Sun Direction",
		default = False)

	OctaneRenderSettings.active_light = StringProperty(
		name=getLabel('active_light'),
		description="Set a Sun Light Source",
		maxlen = 128,
		default = "")

# Octane Export Settings

	# Context
	OctaneRenderSettings.export_sel_only = BoolProperty(
		name="Selection Only",
		description="Only export objects in visible selection. Else export whole scene.",
		default = False)

	OctaneRenderSettings.export_remove_hidden = BoolProperty(
		name="Remove Hidden",
		description="Remove hidden objects from export result",
		default = False)

	# Output Opyions
	OctaneRenderSettings.export_apply_modifiers = BoolProperty(
		name="Apply Modifiers",
		description="Use transformed mesh data from each object. May break vert order for morph targets.",
		default = True)

	OctaneRenderSettings.export_ROTX90=BoolProperty(
		name="Rotate X90",
		description="Rotate on export so Blenders UP is translated into OBJs UP",
		default = True)

	OctaneRenderSettings.export_copy_images = BoolProperty(
		name="Copy Images",
		description="Copy image files to the export directory, never overwrite.",
		default = True)

	# Export Options
	OctaneRenderSettings.export_edges = BoolProperty(
		name="Edges",
		description="Edges not connected to faces.",
		default = False)

	OctaneRenderSettings.export_tri=BoolProperty(
		name="Triangulate",
		description="Triangulate quads.",
		default = False)

	OctaneRenderSettings.export_materials = BoolProperty(
		name="Materials",
		description="Write a separate MTL file with the OBJ.",
		default = True)

	OctaneRenderSettings.export_UV=BoolProperty(
		name="UVs",
		description="Export texface UV coords.",
		default = True)

	OctaneRenderSettings.export_normals = BoolProperty(
		name="Normals",
		description="Export vertex normal data (Ignored on import).",
		default = True)

	OctaneRenderSettings.export_HQ = BoolProperty(
		name="HQ",
		description="Calculate high quality normals for rendering.",
		default = False)

	OctaneRenderSettings.export_polygroups = BoolProperty(
		name="Polygroups",
		description="Export vertex groups as OBJ groups (one group per face approximation).",
		default = False)

	OctaneRenderSettings.export_curves_as_nurbs = BoolProperty(
		name="Nurbs",
		description="Export 3D nurbs curves and polylines as OBJ curves, (bezier not supported).",
		default = False)

# Octane System settings
	OctaneRenderSettings.binary = StringProperty(
		name="Octane Binary",
		description="Requires Absolute Path",
		maxlen = 128,
		default = "",
		subtype='FILE_PATH')

	OctaneRenderSettings.GPU_selector = BoolProperty(
		name="GPU Devices to use",
		description="Custom GPU devices config",
		default = False)

	OctaneRenderSettings.GPU_use_list = StringProperty(
		name=getLabel('GPU_use_list'),
		description="List of GPUs to use (ex: 0 1 2)",
		maxlen = 128,
		default = "")

	OctaneRenderSettings.resolution = BoolProperty(
		name=getLabel('resolution'),
		description="Export resolution",
		default = True)

	OctaneRenderSettings.verbose = BoolProperty(
		name="Verbose logging in console",
		description="Log Octane plug-in events in console",
		default = True)


