# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 3
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

# Original framework from Netrender
# Original Octane script from Enrico Cerica
# This script by Lionel Zamouth

import bpy
import octanerender.settings
from octanerender.utils import *
from octanerender.labels import getLabel

def base_poll(cls, context):
	rd = context.scene.render
	return (rd.use_game_engine==False) and (rd.engine in cls.COMPAT_ENGINES)

# Main Octane Panel
class OctaneRenderButtonsPanel():
	bl_space_type = "PROPERTIES"
	bl_region_type = "WINDOW"
	bl_context = "render"
	# COMPAT_ENGINES must be defined in each subclass, external engines can add themselves here

	@classmethod
	def poll(cls, context):
		rd = context.scene.render
		return rd.engine == 'OCT_RENDER' and rd.use_game_engine == False 

# Octane Render Plugin Panel
class RENDER_OCT_Octane_Main(OctaneRenderButtonsPanel, bpy.types.Panel):
	bl_label = "Octane/OBJ Export Version " + octanerender.Version
	COMPAT_ENGINES = {'OCT_RENDER'}    

	@classmethod
	def poll(cls, context):
		return super().poll(context)

	def draw(self, context):
		layout = self.layout
		scene = context.scene
		octane_render = scene.octane_render

		row = layout.row()
		row.label(text=" Octane Project Configuration", icon='SCRIPTWIN')
		row = layout.row()
		split=row.split(percentage=0.80)
		col = split.column()
		col.prop(octane_render, "binary")
		row = layout.row()
		split=row.split(percentage=0.80)
		col = split.column()
		col.prop(octane_render, "path")
		row = layout.row()
		split=row.split(percentage=0.82)
		col = split.column()
		col.prop(octane_render, "project_name")

		col = split.column()
		col.prop(octane_render, "replace_project")

		row = layout.row()
		split=row.split(percentage=0.82)
		col = split.column()
		col.prop(octane_render, "unit_size")
		col = split.column()

# Export Configuration Panel
class RENDER_OCT_Octane_Export_Configuration(OctaneRenderButtonsPanel, bpy.types.Panel):
	bl_label = "Octane Export Configuration"
	COMPAT_ENGINES = {'OCT_RENDER'}

	def draw(self, context):
		layout = self.layout

		scene = context.scene
		octane_render = scene.octane_render
		rd = scene.render

		# Film
		row = layout.row()
		row.label(text=" Film", icon='SCENE')
		row = layout.row()
		split = row.split(percentage=0.25)
		col = split.column()
		col.prop(octane_render, "resolution")

		if octane_render.resolution:
			split = split.split(percentage=0.35)
			col = split.column()
			col.prop(rd, "resolution_x",text='Width')
			split = split.split(percentage=0.6)
			col = split.column()
			col.prop(rd, "resolution_y",text='Height')
			col = split.column()
			col.prop(rd, "resolution_percentage",text='')

		# Camera
		row = layout.row()
		split = row.split(percentage=0.25)
		col = split.column()
		col.prop(octane_render, "export_camera")
		if octane_render.export_camera:
			split = split.split(percentage=0.75)
			col = split.column()
			col.prop(octane_render, "active_camera")

			col = split.column()
			col.operator("button_select_camera",icon='SCENE')

			row = layout.row()
			split = row.split(percentage=0.25)
			col = split.column()
			col.prop(octane_render, "lens_aperture")
			if octane_render.lens_aperture:
				split = split.split(percentage=0.75)
				col = split.column()
				col.prop(octane_render, "lens_aperture_value")
				col = split.column()
				col.prop(octane_render, "lens_aperture_curve")

			row = layout.row()
			split = row.split(percentage=0.25)
			col = split.column()
			col.prop(octane_render, "focal_depth")
			if octane_render.focal_depth:
				split = split.split(percentage=0.75)
				col = split.column()
				col.prop(octane_render, "focal_depth_value")
				col = split.column()
				col.prop(octane_render, "focal_depth_curve")

			row = layout.row()
			split = row.split(percentage=0.25)
			col = split.column()
			col.prop(octane_render, "camera_motion")
			if octane_render.camera_motion:
				split = split.split(percentage=0.75)
				col = split.column()
				col.prop(octane_render, "interpolate_frame")
				col = split.column()
			
		# Day light environment
		layout.separator()
		row = layout.row()
		row.label(text=" Daylight Environment", icon='LAMP_SUN')
		row = layout.row()
		split = row.split(percentage=0.25)
		col = split.column()
		col.prop(octane_render, "export_sundir")
		if octane_render.export_sundir:
			split = split.split(percentage=0.75)
			col = split.column()
			col.prop(octane_render, "active_light")
			col = split.column()
			col.operator("button_select_light_source", icon='LAMP_SUN')

		# GPU Devices
		row = layout.row()
		split = row.split(percentage=0.33)
		col = split.column()
		col.prop(octane_render, "GPU_selector")
		if octane_render.GPU_selector:
			col = split.column()
			col.prop(octane_render, "GPU_use_list")

# Octane Export Panel
class RENDER_OCT_project_settings(OctaneRenderButtonsPanel, bpy.types.Panel):
	bl_label = "Octane Export"
	COMPAT_ENGINES = {'OCT_RENDER'}    

	@classmethod
	def poll(cls, context):
		return super().poll(context)

	def draw(self, context):
		layout = self.layout

		scene = context.scene
		octane_render = scene.octane_render

		# Frame
		row = layout.row()
		row.label(text=" Frame", icon='SEQUENCE')
		row = layout.row()
		col = row.column()
		col.operator("button_export",icon='SCENE_DATA')
		col = row.column()
		col.operator("button_render", icon='RENDER_STILL')
		
		# Animation
		layout.separator()
		row = layout.row()
		row.label(text=" Animation", icon='CAMERA_DATA')
		row = layout.row()

		col = row.column()
		col.prop(octane_render, "image_output")
		
		row = layout.row()
		col = row.column()
		col.prop(scene, "frame_start",text="Start")
		col = row.column()
		col.prop(scene, "frame_end",text="End")
		col = row.column()
		col.prop(scene, "frame_step",text="Step")

		row = layout.row()
		col = row.column()
		col.prop(octane_render, "export_samples_per_image")
		col = row.column()
		col.operator_menu_enum('menu_export_presets','export_samples_presets','Samples Presets')
		col = row.column()
		col.operator("button_animation",icon='RENDER_ANIMATION')

# Octane Advanced Panel
class RENDER_OCT_Advanced(OctaneRenderButtonsPanel, bpy.types.Panel):
	bl_label = "Octane Advanced"
	#bl_options = {'DEFAULT_CLOSED'}
	COMPAT_ENGINES = {'OCT_RENDER'}    

	@classmethod
	def poll(cls, context):
		return super().poll(context)

	def draw(self, context):
		layout = self.layout

		scene = context.scene
		octane_render = scene.octane_render

		# Context
		row = layout.row()
		row.label(text=" Context",icon='GROUP')
		row = layout.row()
		split = row.split(percentage=0.25)
		col = split.column()
		col.prop(octane_render, "export_sel_only")
		col = split.column()
		col.prop(octane_render, "export_remove_hidden")
		
		# Output options
		layout.separator()
		row = layout.row()
		row.label(text=" Output Options",icon='MOD_MESHDEFORM')
		row = layout.row()
		split = row.split(percentage=0.25)

		col = split.column()
		col.prop(octane_render, "export_apply_modifiers")
		col = split.column()
		col.prop(octane_render, "export_ROTX90")
		col = split.column()
		col.prop(octane_render, "export_copy_images")
		col = split.column()

		layout.separator()
		row = layout.row()
		row.label(text=" Export Options",icon='SETTINGS')

		row = layout.row()
		split = row.split(percentage=0.25)
		col = split.column()
		col.prop(octane_render, "export_edges")
		col = split.column()
		col.prop(octane_render, "export_tri")
		col = split.column()
		col.prop(octane_render, "export_materials")
		col = split.column()
		col.prop(octane_render, "export_UV")

		row = layout.row()
		split = row.split(percentage=0.25)
		col = split.column()
		col.prop(octane_render, "export_normals")
		col = split.column()
		col.prop(octane_render, "export_HQ")
		col = split.column()
		col.prop(octane_render, "export_polygroups")
		col = split.column()
		col.prop(octane_render, "export_curves_as_nurbs")

