# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 3
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

# Original framework from Netrender
# Original Octane script from Enrico Cerica
# This script by Lionel Zamouth

import os
import bpy
import datetime
import unicodedata
import octanerender

def elapsed_short(start):
	delta = datetime.datetime.now() - start
	return '%d.%03d secs' % (delta.seconds,delta.microseconds/1000)

def elapsed_long(start):
	delta = datetime.datetime.now() - start
	if delta.days == 0:
		return '%dh%dm%d.%02d' % (delta.seconds/3600, delta.seconds%3600/60, delta.seconds%60, delta.microseconds/10000)
	else:
		return '%dd %dh%dm%d.%02d' % (delta.days, delta.seconds/3600, delta.seconds%3600/60, delta.seconds%60, delta.microseconds/10000)

def notify_user( there ):
	if octanerender.Status_Severity == 0:
		there.report({'INFO'}, octanerender.Status_Text)
	if octanerender.Status_Severity == 1:
		there.report({'WARNING'}, octanerender.Status_Text)
	if octanerender.Status_Severity == 2:
		there.report({'ERROR'}, octanerender.Status_Text)

def update_status(severity,status):
	# 0 = Info
	# 1 = Warning
	# 2 = Error
	octanerender.Status_Severity = severity
	octanerender.Status_Text = status
	octanerender.Status_Display = True
	if severity == 0:
		log ('Status set to Info: ' + status)
	elif severity == 1:
		log ('Status set to Warning: ' + status)
	elif severity == 2:
		log ('Status set to Error: ' + status)
	else:
		# to avoid preset of error log into console
		octanerender.Status_Severity = 2

def log(log):
	if octanerender.Verbose:
		print ('Octane plug-in ' + octanerender.Version + ' on %d.%d.%d' % tuple(bpy.app.version) + '.' + (bpy.app.build_revision) + ' : ' + (log))

def error(error):
	update_status(2,error)
	raise Exception("Octane plug-in: "+error)

def matrix_vect(mat,vec):
	vecr = [0.,0.,0.,0.,0.]
	for i in range(4):
		for j in range(4):
			vecr[i] += vec[j] * mat[j][i] 
	return vecr
		
def rotate90x(vect):
	return [vect[0],vect[2],-vect[1]]

def absPath(name):
	return os.path.abspath( bpy.path.abspath(name) )

def hasSpace(name):
	if name.find(' ') < 0:
		return False
	else:
		return True

def fixName(name):
	res = ''
	if name == None:
		res = 'None'
	else:
		res = unicodedata.normalize('NFKD', name).encode('ascii','ignore').decode('ascii','ignore').replace(' ','_')
	if name != res:
		log ('Fixed name <%s> to <%s>' % (name,res))
	return res

def copy_file(source, dest):
	log ('Copying file "%s" to "%s"' % (source,dest))
	file = open(source, 'rb')
	data = file.read()
	file.close()
	file = open(dest, 'wb')
	file.write(data)
	file.close()

	

